/* ViewDelegator.m     UIView subclasses to delegate GUI methods
 *
 * Copyright (c) 2011 Psellos   http://psellos.com
 * Licensed under the MIT license:
 *     http://www.opensource.org/licenses/mit-license.php
 *
 * ViewDelegator is a direct subclass of UIView that delegates its GUI
 * methods.  ViewDelegatorGL is a subclass of ViewDelegator that
 * specifies its layer class as CAEAGLLayer, so it can be used for
 * OpenGL ES drawing.
 *
 * These classes are logically a small extension of Cocoa Touch.  They
 * don't know anything about OCaml.
 */
#import <UIKit/UIKit.h>
#import <QuartzCore/QuartzCore.h>

#import "ViewDelegator.h"

@implementation ViewDelegator

@dynamic delegate;

- (NSObject<ViewDelegate> *) delegate
{
    return delegate;
}


- (void) setDelegate: (NSObject<ViewDelegate> *) aDelegate
{
    delegate = aDelegate;
}


- (void) layoutSubviews
{
    if([delegate respondsToSelector: @selector(viewLayoutSubviews:)])
        [delegate viewLayoutSubviews: self];
}
@end


@implementation ViewDelegatorGL

/* A subclass of ViewDelegator for OpenGL ES graphics.
 */

+ (Class) layerClass {
    return [CAEAGLLayer class];
}

@end
